@@ -25,8 +25,7 @@ pub fn connect(url: &str, user: &str, password: &str) -> Result<Connection, Erro
       let active_url = conn.get_active_url().unwrap();
       drop(conn);
       let admin_active_url = format!("<$admin>:{}",active_url);
-      let conn2 = super::connect(&admin_active_url,user,password);
-      conn2
+      super::connect(&admin_active_url,user,password)
     },
     Err(err)=> Err(err)
   }
@@ -99,98 +98,80 @@ pub fn list_all_queues(session: &Session) -> Result<Vec<QueueInfo>,Error> {
   let query_result = session.request_reply(&admin_queue, msg, TIMEOUT);
   match query_result{
     Ok(response) =>{
-      match response{
-        Some(resp)=>{
-          match &resp {
-            Message::MapMessage(map_message) => {
-              //got response message
-              for (key,val) in &map_message.body {
-                let q_info: &MapMessage = extract!(TypedValue::Map(_), val).expect("extract inner message");
-                let pending_messages = extract!(TypedValue::String(_), q_info.body.get("nm").unwrap()).expect("extract pending messages");
-                let max_bytes = extract!(TypedValue::String(_), q_info.body.get("mb").unwrap()).expect("extract max bytes");
-                let max_msgs = extract!(TypedValue::String(_), q_info.body.get("mm").unwrap()).expect("extract max messages");
-                let overflow = extract!(TypedValue::String(_), q_info.body.get("op").unwrap()).expect("extract overflow");
-                let overflow_policy: OverflowPolicy;
-                match overflow.as_str() {
-                  "0"=> overflow_policy=OverflowPolicy::Default,
-                  "1"=> overflow_policy=OverflowPolicy::DiscardOld,
-                  "2"=> overflow_policy=OverflowPolicy::RejectIncoming,
-                  _ => overflow_policy=OverflowPolicy::Default,
-                }
-                let mut bool_failsafe = false;
-                match q_info.body.get("failsafe") {
-                  Some(val) => {
-                    let failsafe = extract!(TypedValue::String(_), val).expect("extract failsafe");
-                    bool_failsafe = failsafe == "1";
-                  },
-                  None =>{},
-                }
-                let mut bool_secure = false;
-                match q_info.body.get("secure") {
-                  Some(val) => {
-                    let secure = extract!(TypedValue::String(_), val).expect("extract secure flag");
-                    bool_secure = secure == "1";
-                  },
-                  None =>{},
-                }
-                let mut bool_global = false;
-                match q_info.body.get("global") {
-                  Some(val) => {
-                    let global = extract!(TypedValue::String(_), val).expect("extract global flag");
-                    bool_global = global == "1";    
-                  },
-                  None =>{},
-                }
-                let mut bool_sender_name = false;
-                match q_info.body.get("sname") {
-                  Some(val) => {
-                    let sender_name = extract!(TypedValue::String(_), val).expect("extract sender name");
-                    bool_sender_name = sender_name == "1";
-                  },
-                  None =>{},
-                }
-                let mut bool_sn_enforced = false;
-                match q_info.body.get("snameenf") {
-                  Some(val) => {
-                    let sn_enforced = extract!(TypedValue::String(_), val).expect("extrance sender name enforced");
-                    bool_sn_enforced = sn_enforced == "1";    
-                  },
-                  None =>{},
-                }
-                let prefetch = extract!(TypedValue::String(_), q_info.body.get("pf").unwrap()).expect("queue property");
-                let consumer_count = extract!(TypedValue::String(_), q_info.body.get("cc").unwrap()).expect("queue property");
-                let expiry = extract!(TypedValue::String(_), q_info.body.get("expy").unwrap()).expect("queue property");
-                let redelivery_delay = extract!(TypedValue::String(_), q_info.body.get("rdd").unwrap()).expect("queue property");
-                let in_total_count = extract!(TypedValue::String(_), q_info.body.get("inct").unwrap()).expect("queue property");
-                let out_total_count = extract!(TypedValue::String(_), q_info.body.get("outct").unwrap()).expect("queue property");
-                                    
-                let queue_info = QueueInfo{
-                  name: key.to_string(),
-                  pending_messages: Some(pending_messages.parse::<i64>().unwrap()),
-                  max_messages: Some(max_msgs.parse::<i64>().unwrap()),
-                  max_bytes: Some(max_bytes.parse::<i64>().unwrap()),
-                  overflow_policy: Some(overflow_policy),
-                  failsafe: Some(bool_failsafe),
-                  secure: Some(bool_secure),
-                  global: Some(bool_global),
-                  sender_name: Some(bool_sender_name),
-                  sender_name_enforced: Some(bool_sn_enforced),
-                  prefetch: Some(prefetch.parse::<i32>().unwrap()),
-                  expiry_override: Some(expiry.parse::<i64>().unwrap()),
-                  redelivery_delay: Some(redelivery_delay.parse::<i64>().unwrap()),
-                  consumer_count: Some(consumer_count.parse::<i32>().unwrap()),
-                  incoming_total_count: Some(in_total_count.parse::<i64>().unwrap()),
-                  outgoing_total_count: Some(out_total_count.parse::<i64>().unwrap()),
-                };
-                queues.push(queue_info);
+      if let Some(resp) = response {
+        match &resp {
+          Message::MapMessage(map_message) => {
+            //got response message
+            for (key,val) in &map_message.body {
+              let q_info: &MapMessage = extract!(TypedValue::Map(_), val).expect("extract inner message");
+              let pending_messages = extract!(TypedValue::String(_), q_info.body.get("nm").unwrap()).expect("extract pending messages");
+              let max_bytes = extract!(TypedValue::String(_), q_info.body.get("mb").unwrap()).expect("extract max bytes");
+              let max_msgs = extract!(TypedValue::String(_), q_info.body.get("mm").unwrap()).expect("extract max messages");
+              let overflow = extract!(TypedValue::String(_), q_info.body.get("op").unwrap()).expect("extract overflow");
+              let overflow_policy: OverflowPolicy;
+              match overflow.as_str() {
+                "0"=> overflow_policy=OverflowPolicy::Default,
+                "1"=> overflow_policy=OverflowPolicy::DiscardOld,
+                "2"=> overflow_policy=OverflowPolicy::RejectIncoming,
+                _ => overflow_policy=OverflowPolicy::Default,
               }
-            },
-            _ =>{
-              warn!("unkown response from queue information request")
+              let mut bool_failsafe = false;
+              if let Some(val) = q_info.body.get("failsafe") {
+                let failsafe = extract!(TypedValue::String(_), val).expect("extract failsafe");
+                bool_failsafe = failsafe == "1";
+              }
+              let mut bool_secure = false;
+              if let Some(val) = q_info.body.get("secure") {
+                let secure = extract!(TypedValue::String(_), val).expect("extract secure flag");
+                bool_secure = secure == "1";
+              }
+              let mut bool_global = false;
+              if let Some(val) = q_info.body.get("global") {
+                let global = extract!(TypedValue::String(_), val).expect("extract global flag");
+                bool_global = global == "1";
+              }
+              let mut bool_sender_name = false;
+              if let Some(val) = q_info.body.get("sname") {
+                let sender_name = extract!(TypedValue::String(_), val).expect("extract sender name");
+                bool_sender_name = sender_name == "1";
+              }
+              let mut bool_sn_enforced = false;
+              if let Some(val) = q_info.body.get("snameenf") {
+                let sn_enforced = extract!(TypedValue::String(_), val).expect("extrance sender name enforced");
+                bool_sn_enforced = sn_enforced == "1";
+              }
+              let prefetch = extract!(TypedValue::String(_), q_info.body.get("pf").unwrap()).expect("queue property");
+              let consumer_count = extract!(TypedValue::String(_), q_info.body.get("cc").unwrap()).expect("queue property");
+              let expiry = extract!(TypedValue::String(_), q_info.body.get("expy").unwrap()).expect("queue property");
+              let redelivery_delay = extract!(TypedValue::String(_), q_info.body.get("rdd").unwrap()).expect("queue property");
+              let in_total_count = extract!(TypedValue::String(_), q_info.body.get("inct").unwrap()).expect("queue property");
+              let out_total_count = extract!(TypedValue::String(_), q_info.body.get("outct").unwrap()).expect("queue property");
+                                  
+              let queue_info = QueueInfo{
+                name: key.to_string(),
+                pending_messages: Some(pending_messages.parse::<i64>().unwrap()),
+                max_messages: Some(max_msgs.parse::<i64>().unwrap()),
+                max_bytes: Some(max_bytes.parse::<i64>().unwrap()),
+                overflow_policy: Some(overflow_policy),
+                failsafe: Some(bool_failsafe),
+                secure: Some(bool_secure),
+                global: Some(bool_global),
+                sender_name: Some(bool_sender_name),
+                sender_name_enforced: Some(bool_sn_enforced),
+                prefetch: Some(prefetch.parse::<i32>().unwrap()),
+                expiry_override: Some(expiry.parse::<i64>().unwrap()),
+                redelivery_delay: Some(redelivery_delay.parse::<i64>().unwrap()),
+                consumer_count: Some(consumer_count.parse::<i32>().unwrap()),
+                incoming_total_count: Some(in_total_count.parse::<i64>().unwrap()),
+                outgoing_total_count: Some(out_total_count.parse::<i64>().unwrap()),
+              };
+              queues.push(queue_info);
             }
+          },
+          _ =>{
+            warn!("unkown response from queue information request")
           }
-        },
-        None=>{},
+        }
       }
     },
     Err(err) =>{
@@ -209,23 +190,17 @@ pub fn create_queue(session: &Session, queue: &QueueInfo) -> Result<(),Error>{
   let mut msg: MapMessage = Default::default();
   msg.body.insert("dn".to_string(), TypedValue::String(queue.name.clone()));
   msg.body.insert("dt".to_string(), TypedValue::Integer(DESTINATION_TYPE_QUEUE));
-  match queue.max_bytes {
-    Some(val) => {
-      msg.body.insert("mb".to_string(), TypedValue::Long(val));
-    },
-    _ => {},
+  if let Some(val) = queue.max_bytes {
+    msg.body.insert("mb".to_string(), TypedValue::Long(val));
   }
-  match queue.max_messages {
-    Some(val) => {
-      msg.body.insert("mm".to_string(), TypedValue::Long(val));
-    },
-    _ => {},
+  if let Some(val) = queue.max_messages {
+    msg.body.insert("mm".to_string(), TypedValue::Long(val));
   }
-  match queue.global {
-    Some(val) => {
-      msg.body.insert("global".to_string(), TypedValue::Boolean(val));
-    },
-    _ => {},
+  if let Some(val) = queue.global {
+    msg.body.insert("global".to_string(), TypedValue::Boolean(val));
+  }
+  if let Some(val) = queue.prefetch {
+    msg.body.insert("pf".to_string(), TypedValue::Integer(val));
   }
 
   //header
@@ -338,62 +313,56 @@ pub fn list_all_topics(session: &Session) -> Result<Vec<TopicInfo>,Error> {
   let query_result = session.request_reply(&admin_queue, msg, TIMEOUT);
   match query_result{
     Ok(response) =>{
-      match response{
-        Some(resp)=>{
-          match &resp {
-            Message::MapMessage(map_message) => {
-              //got response message
-              for (key,val) in &map_message.body {
-                let t_info: &MapMessage = extract!( TypedValue::Map(_), val).expect("inner message");
-                let mut bool_global = false;
-                match t_info.body.get("global") {
-                  Some(val) => {
-                    let global = extract!( TypedValue::String(_), val).expect("global flag");
-                    bool_global = global == "1";    
-                  },
-                  None =>{},
-                }
-                let prefetch = extract!( TypedValue::String(_), t_info.body.get("pf").unwrap()).expect("extract property");
-                let expiry = extract!( TypedValue::String(_), t_info.body.get("expy").unwrap()).expect("extract property");
-                let max_bytes = extract!( TypedValue::String(_), t_info.body.get("mb").unwrap()).expect("extract property");
-                let max_msgs = extract!( TypedValue::String(_), t_info.body.get("mm").unwrap()).expect("extract property");
-                let durable_count = extract!( TypedValue::String(_), t_info.body.get("cd").unwrap()).expect("extract property");
-                let subscriber_count = extract!( TypedValue::String(_), t_info.body.get("sc").unwrap()).expect("extract property");
-                let pending_messages = extract!( TypedValue::String(_), t_info.body.get("nm").unwrap()).expect("extract property");
-                let in_total_count = extract!( TypedValue::String(_), t_info.body.get("inct").unwrap()).expect("extract property");
-                let out_total_count = extract!( TypedValue::String(_), t_info.body.get("outct").unwrap()).expect("extract property");
-                let overflow = extract!( TypedValue::String(_), t_info.body.get("op").unwrap()).expect("extract property");
-                let overflow_policy: OverflowPolicy;
-                match overflow.as_str() {
-                  "0"=> overflow_policy=OverflowPolicy::Default,
-                  "1"=> overflow_policy=OverflowPolicy::DiscardOld,
-                  "2"=> overflow_policy=OverflowPolicy::RejectIncoming,
-                  _ => overflow_policy=OverflowPolicy::Default,
-                }
-                
-                let topic_info = TopicInfo{
-                  name: key.to_string(),
-                  expiry_override: Some(expiry.parse::<i64>().unwrap()),
-                  global: Some(bool_global),
-                  max_bytes: Some(max_bytes.parse::<i64>().unwrap()),
-                  max_messages: Some(max_msgs.parse::<i64>().unwrap()),
-                  overflow_policy: Some(overflow_policy),
-                  prefetch: Some(prefetch.parse::<i32>().unwrap()),
-                  durable_count: Some(durable_count.parse::<i32>().unwrap()),
-                  subscriber_count: Some(subscriber_count.parse::<i32>().unwrap()),
-                  pending_messages: Some(pending_messages.parse::<i64>().unwrap()),
-                  incoming_total_count: Some(in_total_count.parse::<i64>().unwrap()),
-                  outgoing_total_count: Some(out_total_count.parse::<i64>().unwrap()),
-                };
-                topics.push(topic_info);
+      if let Some(resp) = response {
+        match &resp {
+          Message::MapMessage(map_message) => {
+            //got response message
+            for (key,val) in &map_message.body {
+              let t_info: &MapMessage = extract!( TypedValue::Map(_), val).expect("inner message");
+              let mut bool_global = false;
+              if let Some(val) = t_info.body.get("global") {
+                let global = extract!( TypedValue::String(_), val).expect("global flag");
+                bool_global = global == "1";
               }
-            },
-            _ =>{
-              warn!("unkown response from topic information request")
+              let prefetch = extract!( TypedValue::String(_), t_info.body.get("pf").unwrap()).expect("extract property");
+              let expiry = extract!( TypedValue::String(_), t_info.body.get("expy").unwrap()).expect("extract property");
+              let max_bytes = extract!( TypedValue::String(_), t_info.body.get("mb").unwrap()).expect("extract property");
+              let max_msgs = extract!( TypedValue::String(_), t_info.body.get("mm").unwrap()).expect("extract property");
+              let durable_count = extract!( TypedValue::String(_), t_info.body.get("cd").unwrap()).expect("extract property");
+              let subscriber_count = extract!( TypedValue::String(_), t_info.body.get("sc").unwrap()).expect("extract property");
+              let pending_messages = extract!( TypedValue::String(_), t_info.body.get("nm").unwrap()).expect("extract property");
+              let in_total_count = extract!( TypedValue::String(_), t_info.body.get("inct").unwrap()).expect("extract property");
+              let out_total_count = extract!( TypedValue::String(_), t_info.body.get("outct").unwrap()).expect("extract property");
+              let overflow = extract!( TypedValue::String(_), t_info.body.get("op").unwrap()).expect("extract property");
+              let overflow_policy: OverflowPolicy;
+              match overflow.as_str() {
+                "0"=> overflow_policy=OverflowPolicy::Default,
+                "1"=> overflow_policy=OverflowPolicy::DiscardOld,
+                "2"=> overflow_policy=OverflowPolicy::RejectIncoming,
+                _ => overflow_policy=OverflowPolicy::Default,
+              }
+              
+              let topic_info = TopicInfo{
+                name: key.to_string(),
+                expiry_override: Some(expiry.parse::<i64>().unwrap()),
+                global: Some(bool_global),
+                max_bytes: Some(max_bytes.parse::<i64>().unwrap()),
+                max_messages: Some(max_msgs.parse::<i64>().unwrap()),
+                overflow_policy: Some(overflow_policy),
+                prefetch: Some(prefetch.parse::<i32>().unwrap()),
+                durable_count: Some(durable_count.parse::<i32>().unwrap()),
+                subscriber_count: Some(subscriber_count.parse::<i32>().unwrap()),
+                pending_messages: Some(pending_messages.parse::<i64>().unwrap()),
+                incoming_total_count: Some(in_total_count.parse::<i64>().unwrap()),
+                outgoing_total_count: Some(out_total_count.parse::<i64>().unwrap()),
+              };
+              topics.push(topic_info);
             }
+          },
+          _ =>{
+            warn!("unkown response from topic information request")
           }
-        },
-        None=>{},
+        }
       }
     },
     Err(err) =>{
@@ -411,23 +380,17 @@ pub fn create_topic(session: &Session, topic: &TopicInfo) -> Result<(),Error> {
   let mut msg: MapMessage = Default::default();
   msg.body.insert("dn".to_string(), TypedValue::String(topic.name.clone()));
   msg.body.insert("dt".to_string(), TypedValue::Integer(DESTINATION_TYPE_TOPIC));
-  match topic.max_bytes {
-    Some(val) => {
-      msg.body.insert("mb".to_string(), TypedValue::Long(val));
-    },
-    _ => {},
+  if let Some(val) = topic.max_bytes {
+    msg.body.insert("mb".to_string(), TypedValue::Long(val));
   }
-  match topic.max_messages {
-    Some(val) => {
-      msg.body.insert("mm".to_string(), TypedValue::Long(val));
-    },
-    _ => {},
+  if let Some(val) = topic.max_messages {
+    msg.body.insert("mm".to_string(), TypedValue::Long(val));
   }
-  match topic.global {
-    Some(val) => {
-      msg.body.insert("global".to_string(), TypedValue::Boolean(val));
-    },
-    _ => {},
+  if let Some(val) = topic.global {
+    msg.body.insert("global".to_string(), TypedValue::Boolean(val));
+  }
+  if let Some(val) = topic.prefetch {
+    msg.body.insert("pf".to_string(), TypedValue::Integer(val));
   }
 
   //header
@@ -492,29 +455,26 @@ pub fn create_bridge(session: &Session, bridge: &BridgeInfo) -> Result<(),Error>
   match bridge.source.clone() {
     Destination::Queue(name) =>{
       msg.body.insert("st".to_string(), TypedValue::Integer(DESTINATION_TYPE_QUEUE));
-      msg.body.insert("sn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("sn".to_string(), TypedValue::String(name));
     },
     Destination::Topic(name) =>{
       msg.body.insert("st".to_string(), TypedValue::Integer(DESTINATION_TYPE_TOPIC));
-      msg.body.insert("sn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("sn".to_string(), TypedValue::String(name));
     },
   }
 
   match bridge.target.clone() {
     Destination::Queue(name) =>{
       msg.body.insert("tt".to_string(), TypedValue::Integer(DESTINATION_TYPE_QUEUE));
-      msg.body.insert("tn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("tn".to_string(), TypedValue::String(name));
     },
     Destination::Topic(name) =>{
       msg.body.insert("tt".to_string(), TypedValue::Integer(DESTINATION_TYPE_TOPIC));
-      msg.body.insert("tn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("tn".to_string(), TypedValue::String(name));
     },
   }
-  match bridge.selector.clone() {
-    Some(sel) => {
-      msg.body.insert("sel".to_string(), TypedValue::String(sel));
-    },
-    None => {},
+  if let Some(sel) = bridge.selector.clone() {
+    msg.body.insert("sel".to_string(), TypedValue::String(sel));
   }
   //header
   let mut header: HashMap<String,TypedValue> = HashMap::new();
@@ -544,22 +504,22 @@ pub fn delete_bridge(session: &Session, bridge: &BridgeInfo) -> Result<(),Error>
   match bridge.source.clone() {
     Destination::Queue(name) =>{
       msg.body.insert("st".to_string(), TypedValue::Integer(DESTINATION_TYPE_QUEUE));
-      msg.body.insert("sn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("sn".to_string(), TypedValue::String(name));
     },
     Destination::Topic(name) =>{
       msg.body.insert("st".to_string(), TypedValue::Integer(DESTINATION_TYPE_TOPIC));
-      msg.body.insert("sn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("sn".to_string(), TypedValue::String(name));
     },
   }
 
   match bridge.target.clone() {
     Destination::Queue(name) =>{
       msg.body.insert("tt".to_string(), TypedValue::Integer(DESTINATION_TYPE_QUEUE));
-      msg.body.insert("tn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("tn".to_string(), TypedValue::String(name));
     },
     Destination::Topic(name) =>{
       msg.body.insert("tt".to_string(), TypedValue::Integer(DESTINATION_TYPE_TOPIC));
-      msg.body.insert("tn".to_string(), TypedValue::String(name.to_string()));
+      msg.body.insert("tn".to_string(), TypedValue::String(name));
     },
   }
   //header
@@ -606,24 +566,21 @@ pub fn get_server_state(session: &Session) -> Result<ServerState,Error> {
   let query_result = session.request_reply(&admin_queue, msg, TIMEOUT);
   match query_result{
     Ok(response) =>{
-      match response{
-        Some(resp)=>{
-          match &resp {
-            Message::MapMessage(map_message) => {
-              //got response message
-              let state_str = extract!( TypedValue::String(_), map_message.body.get("state").unwrap()).expect("extract server status");
-              if state_str == "3"{
-                return Ok(ServerState::Standby);
-              }else{
-                return Ok(ServerState::Active);
-              }
-            },
-            _ =>{
-              warn!("unkown response from queue information request")
+      if let Some(resp) = response {
+        match &resp {
+          Message::MapMessage(map_message) => {
+            //got response message
+            let state_str = extract!( TypedValue::String(_), map_message.body.get("state").unwrap()).expect("extract server status");
+            if state_str == "3"{
+              return Ok(ServerState::Standby);
+            }else{
+              return Ok(ServerState::Active);
             }
+          },
+          _ =>{
+            warn!("unkown response from queue information request")
           }
-        },
-        None=>{},
+        }
       }
     },
     Err(err) =>{
@@ -631,7 +588,7 @@ pub fn get_server_state(session: &Session) -> Result<ServerState,Error> {
       return Err(err);
     }
   }
-  return Ok(ServerState::Active);
+  Ok(ServerState::Active)
 }
 
 /// holds static bridge information
